'''
Created on 2022-03-06

@author: wf
'''

class Version(object):
    '''
    Version handling for pyLoDStorage
    '''
    name="pylodstorage"
    version='0.2.4'
    date = '2020-09-10'
    updated = '2022-06-20'